@@ -1,4 +1,4 @@
-/*	$OpenBSD: ntpd.h,v 1.91 2008/01/28 11:45:59 mpf Exp $ */
+/*	$OpenBSD: ntpd.h,v 1.95 2008/06/10 03:46:09 naddy Exp $ */
 
 /*
  * Copyright (c) 2003, 2004 Henning Brauer <henning@openbsd.org>
@@ -54,7 +54,6 @@
 #define	QUERYTIME_MAX		15	/* single query might take n secs max */
 #define	OFFSET_ARRAY_SIZE	8
 #define	SENSOR_OFFSETS		7
-#define	SETTIME_MIN_OFFSET	180	/* min offset for settime at start */
 #define	SETTIME_TIMEOUT		15	/* max seconds to wait with -s */
 #define	LOG_NEGLIGEE		32	/* negligible drift to not log (ms) */
 #define	FREQUENCY_SAMPLES	8	/* samples for est. of permanent drift */
@@ -98,7 +97,6 @@ struct ntp_status {
 	double		rootdispersion;
 	double		reftime;
 	u_int32_t	refid;
-	u_int32_t	refid4;
 	u_int32_t	send_refid;
 	u_int8_t	synced;
 	u_int8_t	leap;
@@ -141,6 +139,7 @@ struct ntp_sensor {
 	time_t				 next;
 	time_t				 last;
 	char				*device;
+	u_int32_t			 refid;
 	int				 sensordevid;
 	int				 correction;
 	u_int8_t			 weight;
@@ -150,6 +149,7 @@ struct ntp_sensor {
 struct ntp_conf_sensor {
 	TAILQ_ENTRY(ntp_conf_sensor)		 entry;
 	char					*device;
+	char					*refstr;
 	int					 correction;
 	u_int8_t				 weight;
 };
